@@ -11,6 +11,7 @@
 #include "CoordgenMinimizer.h"
 #include "sketcherMinimizer.h"
 #include "sketcherMinimizerFragment.h"
+#include "sketcherMinimizerRing.h"
 #include "sketcherMinimizerStretchInteraction.h"
 
 using namespace std;
@@ -20,10 +21,16 @@ const int PERFECTLY_PLANAR_SYSTEM_SCORE = 50;
 const int NON_PLANAR_SYSTEM_SCORE = 1000;
 const int UNTREATABLE_SYSTEM_PLANARITY_SCORE = 200000;
 
+const int MACROCYCLE_CENTRAL_RING_SCORE = 1000;
+const int NUMBER_OF_FUSED_RINGS_CENTRAL_RING_SCORE = 40;
+const int NUMBER_OF_FUSION_ATOMS_CENTRAL_RING_SCORE = 15;
+const int NEIGHBOR_ALREADY_BUILT_RING_SCORE = 100000;
+
+
 void CoordgenFragmentBuilder::initializeCoordinates(
     sketcherMinimizerFragment* fragment) const
 {
-    assert(fragment->getAtoms().size());
+    assert(!fragment->getAtoms().empty());
     buildFragment(fragment);
     fragment->storeCoordinateInformation();
 }
@@ -59,7 +66,7 @@ void CoordgenFragmentBuilder::rotateMainFragment(
         constrainOldCenter += a->templateCoordinates;
         constrainNewCenter += a->coordinates;
     }
-    if (constrainedAtoms.size() > 0) {
+    if (!constrainedAtoms.empty()) {
         constrainOldCenter /= constrainedAtoms.size();
         constrainNewCenter /= constrainedAtoms.size();
     }
@@ -137,7 +144,7 @@ bool CoordgenFragmentBuilder::findTemplate(
     for (auto& temp : sketcherMinimizer::m_templates.getTemplates()) {
         foundTemplate = sketcherMinimizer::compare(atoms, bonds, temp, mapping);
         if (foundTemplate) {
-            if (atoms.size() > 0) {
+            if (!atoms.empty()) {
                 atoms[0]->fragment->isTemplated = true;
             }
             for (unsigned int i = 0; i < atoms.size(); i++) {
@@ -164,14 +171,24 @@ sketcherMinimizerRing* CoordgenFragmentBuilder::findCentralRingOfSystem(
     size_t high_score = 0;
     for (sketcherMinimizerRing* r : rings) {
         size_t priority = 0;
+        /*keep growing the system building rings neighboring already built rings*/
+        for (auto neighborRing : r->fusedWith) {
+            if (neighborRing->coordinatesGenerated) {
+                priority += NEIGHBOR_ALREADY_BUILT_RING_SCORE;
+                break;
+            }
+        }
         if (r->isMacrocycle()) {
-            priority += 1000;
+            priority += MACROCYCLE_CENTRAL_RING_SCORE;
         }
         if (r->_atoms.size() == 6) {
-            priority += 100;
+            priority += 10;
         }
         priority += r->_atoms.size();
-        priority += 10 * (r->fusedWith.size());
+        priority += NUMBER_OF_FUSED_RINGS_CENTRAL_RING_SCORE * (r->fusedWith.size());
+        for (auto fusionAtoms : r->fusionAtoms) {
+            priority+= NUMBER_OF_FUSION_ATOMS_CENTRAL_RING_SCORE * fusionAtoms.size();
+        }
         if (priority > high_score || highest == nullptr) {
             highest = r;
             high_score = priority;
@@ -198,7 +215,7 @@ void CoordgenFragmentBuilder::generateCoordinatesCentralRings(
                 if (needsTemplate) {
                     findTemplate(rings);
                 }
-                while (rings.size() != 0) {
+                while (!rings.empty()) {
                     auto centralRing = findCentralRingOfSystem(rings);
                     buildRing(centralRing);
                     rings.erase(
@@ -226,7 +243,6 @@ float CoordgenFragmentBuilder::newScorePlanarity(
     const // if score > 1000 then it is not planar
 {
     float score = 0.f;
-
     for (const auto& ring : rings) {
         if (ring->isMacrocycle() &&
             m_macrocycleBuilder.findBondToOpen(ring) == nullptr) {
@@ -263,7 +279,7 @@ float CoordgenFragmentBuilder::newScorePlanarity(
 void CoordgenFragmentBuilder::generateCoordinatesSideRings(
     stack<sketcherMinimizerRing*> sideRings) const
 {
-    while (sideRings.size()) {
+    while (!sideRings.empty()) {
         sketcherMinimizerRing* ring = sideRings.top();
         sideRings.pop();
         buildRing(ring);
@@ -278,15 +294,12 @@ CoordgenFragmentBuilder::getSharedAtomsWithAlreadyDrawnRing(
 {
     sketcherMinimizerRing* parent = nullptr;
     for (auto i : ring->fusedWith) {
-
         if (i->coordinatesGenerated) {
-            if (!parent) {
-                parent = i;
-            } else {
-                if (i->_atoms.size() > parent->_atoms.size()) {
-                    parent = i;
-                }
+            if (parent != nullptr) {
+                if (i->getFusionAtomsWith(ring).size() < parent->getFusionAtomsWith(ring).size() ||
+                (i->size() < parent->size())) continue;
             }
+            parent = i;
         }
     }
     if (parent) {
@@ -372,7 +385,7 @@ void CoordgenFragmentBuilder::buildRing(sketcherMinimizerRing* ring) const
                 pivotAtom = fusionAtoms.at(0);
                 pivotAtomOnParent = fusionAtoms.at(0);
             } else {
-                assert(fusionBond != NULL);
+                assert(fusionBond != nullptr);
                 if (find(atoms.begin(), atoms.end(),
                          fusionBond->getStartAtom()) != atoms.end()) {
                     pivotAtom = fusionBond->getStartAtom();
@@ -518,15 +531,7 @@ void CoordgenFragmentBuilder::buildRing(sketcherMinimizerRing* ring) const
             for (unsigned int i = 0; i < atoms.size(); i++) {
                 atoms[i]->setCoordinates((*targetCoords)[i]);
             }
-            // TODO forbid if double bond to ring
-            if (ring->fusedWith.size() == 1 &&
-                (*fusionAtoms.begin())->hasNoStereoActiveBonds() &&
-                (*fusionAtoms.rbegin())->hasNoStereoActiveBonds()) {
-                auto* dof = new CoordgenFlipRingDOF(ring, fusionAtoms);
-                ring->getAtoms().at(0)->fragment->addDof(dof);
-            }
         }
-
     } else {
         for (unsigned int i = 0; i < coords.size(); i++) {
             atoms[i]->setCoordinates(coords[i]);
@@ -540,7 +545,7 @@ CoordgenFragmentBuilder::listOfCoordinatesFromListofRingAtoms(
     const vector<sketcherMinimizerAtom*>& atoms)
 {
     vector<sketcherMinimizerPointF> out;
-    assert(atoms.size());
+    assert(!atoms.empty());
     auto a = static_cast<float>(2 * M_PI / atoms.size());
     sketcherMinimizerPointF coords(0.f, 0.f);
     float angle = 0;
@@ -577,7 +582,7 @@ void CoordgenFragmentBuilder::buildNonRingAtoms(
         isAtomVisited.insert(atomToStartFrom);
     }
 
-    while (q.size()) {
+    while (!q.empty()) {
         generateCoordinatesNeighborsOfFirstAtomInQueue(q, isAtomVisited,
                                                        fragment);
     }
@@ -609,7 +614,7 @@ vector<float> CoordgenFragmentBuilder::neighborsAnglesAtCenter(
             angles.push_back(static_cast<float>(M_PI * 0.5));
         }
     }
-    if (!angles.size()) {
+    if (angles.empty()) {
         for (unsigned int i = 0; i < atom->neighbors.size(); i++) {
             angles.push_back(static_cast<float>(2 * M_PI / angleDivision));
         }
@@ -623,7 +628,7 @@ void CoordgenFragmentBuilder::initializeVariablesForNeighboursCoordinates(
     vector<sketcherMinimizerAtom*>& orderedNeighbors,
     vector<float>& angles) const
 {
-    if (atom->rings.size()) {
+    if (!atom->rings.empty()) {
         return initializeVariablesForNeighboursCoordinatesRingAtom(
             atom, isAtomVisited, startCoordinates, orderedNeighbors, angles);
     }
@@ -824,7 +829,7 @@ void CoordgenFragmentBuilder::avoidZEInversions(
     if (doubleBond == nullptr) {
         return;
     }
-    if (atomsToMirror.size() && doubleBond) {
+    if (!atomsToMirror.empty() && doubleBond) {
         sketcherMinimizerAtom* firstCIPNeighborStart =
             doubleBond->startAtomCIPFirstNeighbor();
         if (firstCIPNeighborStart == nullptr) {
@@ -958,7 +963,7 @@ void CoordgenFragmentBuilder::initializeFusedRingInformation(
                     break;
                 }
             }
-            assert(startAtom != NULL);
+            assert(startAtom != nullptr);
             r->fusionAtoms[i] = orderChainOfAtoms(fusionAtoms, startAtom);
         }
     }
@@ -1034,6 +1039,12 @@ void CoordgenFragmentBuilder::simplifyRingSystem(
                         /* disable rings that share too many atoms */
                         n++;
                     }
+                    if (r->fusionAtoms.at(ringCounter).size() == 3 &&
+                        r->size() == 4 &&
+                        fusedRing->size() == 4) {
+                        /* don't separate rings of bicyclo (1,1,1) pentane so we can use a template instead */
+                        n++;
+                    }
                 }
             }
             if (n == 1) /* ring is fused with only one ring,
