@@ -6,10 +6,10 @@
 #ifndef COORDGEN_MACROCYCLE_BUILDER_H
 #define COORDGEN_MACROCYCLE_BUILDER_H
 
+#include "CoordgenConfig.hpp"
+#include <cstdlib>
 #include <iostream>
 #include <vector>
-#include <cstdlib>
-#include "CoordgenConfig.hpp"
 
 class sketcherMinimizerAtom;
 class sketcherMinimizerRing;
@@ -36,22 +36,28 @@ struct ringConstraint {
 struct vertexCoords {
     bool operator!=(const vertexCoords& rhs) const
     {
-        if (x != rhs.x)
+        if (x != rhs.x) {
             return true;
-        if (y != rhs.y)
+        }
+        if (y != rhs.y) {
             return true;
-        if (z != rhs.z)
+        }
+        if (z != rhs.z) {
             return true;
+        }
         return false;
     }
     bool operator<(const vertexCoords& rhs) const
     {
-        if (x < rhs.x)
+        if (x < rhs.x) {
             return true;
-        if (y < rhs.y)
+        }
+        if (y < rhs.y) {
             return true;
-        if (z < rhs.z)
+        }
+        if (z < rhs.z) {
             return true;
+        }
         return false;
     }
     friend const vertexCoords operator+(const vertexCoords& v1,
@@ -67,9 +73,7 @@ struct vertexCoords {
 
     bool operator==(const vertexCoords& rhs) const
     {
-        if (x == rhs.x && y == rhs.y && z == rhs.z)
-            return true;
-        return false;
+        return x == rhs.x && y == rhs.y && z == rhs.z;
     }
 
     vertexCoords(int ix, int iy, int iz)
@@ -103,9 +107,7 @@ struct hexCoords {
     }
     bool operator==(const hexCoords& rhs) const
     {
-        if (x == rhs.x && y == rhs.y)
-            return true;
-        return false;
+        return x == rhs.x && y == rhs.y;
     }
     int x, y;
     int distanceFrom(const hexCoords& origin) const
@@ -119,9 +121,9 @@ struct hexCoords {
     hexCoords rotate30Degrees()
     {
         int z = -x - y;
-        return hexCoords(-z, -x);
+        return {-z, -x};
     }
-    vertexCoords toVertexCoords() const { return vertexCoords(x, y, -x - y); }
+    vertexCoords toVertexCoords() const { return {x, y, -x - y}; }
 
   private:
     friend std::ostream& operator<<(std::ostream& os, const hexCoords& h);
@@ -133,8 +135,8 @@ struct hexCoords {
 struct Hex {
     Hex(hexCoords coords) : m_coords(coords) {}
     void setCoords(hexCoords coords) { m_coords = coords; }
-    int x() const { return m_coords.x; };
-    int y() const { return m_coords.y; };
+    int x() const { return m_coords.x; }
+    int y() const { return m_coords.y; }
     int z() const { return -x() - y(); }
     hexCoords coords() const { return m_coords; }
     hexCoords m_coords;
@@ -151,9 +153,9 @@ class EXPORT_COORDGEN Polyomino
 {
   public:
     Polyomino();
-    Polyomino(const Polyomino& p);
+    Polyomino(const Polyomino& rhs);
     ~Polyomino();
-    Polyomino& operator=(const Polyomino& rhv);
+    Polyomino& operator=(const Polyomino& rhs);
 
     /*
      explore the topology of the polyominoes and returns true if they have the
@@ -162,7 +164,7 @@ class EXPORT_COORDGEN Polyomino
     bool isTheSameAs(Polyomino& p) const;
 
     /* returns the number of hexagons in the polyomino */
-    int size() const;
+    size_t size() const;
 
     /* empties the polyomino */
     void clear();
@@ -191,7 +193,7 @@ class EXPORT_COORDGEN Polyomino
     vertexCoords findOuterVertex() const;
 
     /* number of Hexs present at the given vertex */
-    int hexagonsAtVertex(vertexCoords v) const;
+    size_t hexagonsAtVertex(vertexCoords v) const;
 
     /* build a round-ish polyomino with the given number of vertices */
     void buildWithVerticesN(int totVertices);
@@ -277,8 +279,8 @@ class EXPORT_COORDGEN Polyomino
 class EXPORT_COORDGEN CoordgenMacrocycleBuilder
 {
   public:
-    CoordgenMacrocycleBuilder() : m_forceOpenMacrocycles(false){};
-    ~CoordgenMacrocycleBuilder(){};
+    CoordgenMacrocycleBuilder() = default;
+    ~CoordgenMacrocycleBuilder() = default;
 
     /* assign coordinates to macrocycle */
     std::vector<sketcherMinimizerPointF>
@@ -299,7 +301,7 @@ class EXPORT_COORDGEN CoordgenMacrocycleBuilder
 
     /* Skip the polyomino approach and fall back to opening the macrocycle when
      * generating coordinates */
-    bool m_forceOpenMacrocycles;
+    bool m_forceOpenMacrocycles = false;
 
     float getPrecision() const;
 
@@ -338,9 +340,10 @@ class EXPORT_COORDGEN CoordgenMacrocycleBuilder
 
     /* build a list of polyominoes with the same number of vertices by removing
      * hexagons with 3 neighbors */
-    std::vector<Polyomino> listOfEquivalent(Polyomino p) const;
+    std::vector<Polyomino> listOfEquivalent(const Polyomino& p) const;
 
-    std::vector<Polyomino> listOfEquivalents(std::vector<Polyomino> l) const;
+    std::vector<Polyomino>
+    listOfEquivalents(const std::vector<Polyomino>& l) const;
 
     /* check that no ring constraints are violated */
     bool checkRingConstraints(std::vector<ringConstraint>& ringConstraints,
@@ -386,9 +389,10 @@ class EXPORT_COORDGEN CoordgenMacrocycleBuilder
                         int& bestStart, int& bestScore) const;
 
     /* write the coordinates of the given path */
-    void writePolyominoCoordinates(std::vector<vertexCoords>& path,
-                                   std::vector<sketcherMinimizerAtom*> atoms,
-                                   int startI) const;
+    void
+    writePolyominoCoordinates(std::vector<vertexCoords>& path,
+                              const std::vector<sketcherMinimizerAtom*>& atoms,
+                              int startI) const;
 
     /* return the coordinates of the given vertex */
     sketcherMinimizerPointF coordsOfVertex(vertexCoords& v) const;
